@@ -8,6 +8,7 @@ from .exceptions import MalformedToken
 from .header import JOSEHeader
 from .jws import JSONWebSignature
 from .jwt import JSONWebToken
+from .oauth2metadataloader import OAuth2MetadataLoader
 from .resolver import JOSEKeyResolver
 
 
@@ -17,6 +18,7 @@ __all__ = [
     'JSONWebSignature',
     'JSONWebToken',
     'JWT',
+    'OAuth2MetadataLoader',
     'parse_jose_object',
 ]
 
